@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy.pm $
-#     $Date: 2008-06-12 13:17:36 -0500 (Thu, 12 Jun 2008) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2443 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Policy;
@@ -47,7 +47,7 @@ use Perl::Critic::Violation qw<>;
 
 use Exception::Class;   # this must come after "use P::C::Exception::*"
 
-our $VERSION = '1.087';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 
@@ -95,9 +95,10 @@ sub new {
     foreach my $parameter ( @parameters ) {
         eval {
             $parameter->parse_and_validate_config_value( $self, $config_object );
-        };
-
-        $errors->add_exception_or_rethrow($EVAL_ERROR);
+        }
+            or do {
+                $errors->add_exception_or_rethrow($EVAL_ERROR);
+            };
 
         $config_object->remove( $parameter->get_name() );
     }
